==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_YOURNAME","Twoje imi i nazwisko");
define("_SORTASC","Sortuj rosnco");
define("_SORTDESC","Sortuj malejco");
define("_CANCEL","Anuluj");
define("_YES","Tak");
define("_NO","Nie");
define("_SCORE","Wynik:");
define("_REPLYMAIN","Komentarz kocowy");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_POSTANON","Wylij anonimowo");
define("_WRITEREVIEW","Napisz recenzj");
define("_WRITEREVIEWFOR","Napisz recenzj dla");
define("_ENTERINFO","Prosimy wpisa informacje zgodnie z zaleceniami");
define("_PRODUCTTITLE","Nazwa produktu");
define("_NAMEPRODUCT","Nazwa recenzowanego produktu.");
define("_REVIEW","Recenzja");
define("_CHECKREVIEW","Twoja aktualna recenzja. Prosimy obserwowa poprawno gramatyczn! Zmie si w 100 sowach, OK? Moesz take uy tagw HTML, jeli wiesz jak ich uywa.");
define("_FULLNAMEREQ","Twoje pene imi i nazwisko. Wymagane.");
define("_REMAIL","Twj email");
define("_REMAILREQ","Twj adres email. Wymagany.");
define("_SELECTSCORE","Wynik tego produktu");
define("_RELATEDLINK","Link");
define("_PRODUCTSITE","Oficjalna strona WWW. Upewnij si, e adres zaczyna si od \"http://\"");
define("_LINKTITLE","Tytu linku");
define("_LINKTITLEREQ","Wymagane, jeli podae link, w innym przypadku - nie.");
define("_RIMAGEFILE","Nazwa pliku z grafik");
define("_RIMAGEFILEREQ","Nazwa tytuowej grafiki, znajdujcej si w images/reviews/. Nie wymagana.");
define("_CHECKINFO","Prosimy upewni si, e wpisana informacja jest w 100% poprawna i uywa poprawnej gramatyki. Przykadowo - prosimy nie pisa wszystkiego DUYMI LITERAMI, bo to odrzucimy.");
define("_INVALIDTITLE","Niepoprawna nazwa... Nie moe by pusta");
define("_INVALIDSCORE","Niepoprawny wynik... Musi by pomidzy 1 a 10");
define("_INVALIDTEXT","Niepoprawna tre... Nie moe by pusta");
define("_INVALIDHITS","Odsony musz by wartoci dodatni");
define("_CHECKNAME","Musisz wpisa zarwno imi, jak i adres email");
define("_INVALIDEMAIL","Niepoprawny email (np: uzytkownik@serwer.pl)");
define("_INVALIDLINK","Musisz wpisa zarwno tytu linku i sam link, albo oba zostawi puste");
define("_ADDED","Dodane:");
define("_REVIEWER","Recenzent:");
define("_REVIEWID","ID recenzji");
define("_HITS","Odson");
define("_LOOKSRIGHT","Czy to wyglda dobrze?");
define("_RMODIFIED","modyfikowane");
define("_RADDED","dodane");
define("_ADMINLOGGED","Bieco zalogowany jako administrator... recenzja zostanie niezwocznie");
define("_RTHANKS","Dzikujemy za wysanie recenzji");
define("_MODIFICATION","modyfikacje");
define("_ISAVAILABLE","Ju jest dostpna w bazie recenzji.");
define("_EDITORWILLLOOK","Redaktorzy spojrz na Twoj recenzj. Powinna by wkrtce dostpna!");
define("_RBACK","Powrt do indeksu recenzji");
define("_RWELCOME","Witamy w sekcji recenzji");
define("_10MOSTPOP","10 najpopularniejszych recenzji");
define("_10MOSTREC","10 ostatnich recenzji");
define("_THEREARE","Aktualnie jest(s)");
define("_REVIEWSINDB","recenzji(e) w bazie");
define("_REVIEWS","Recenzje");
define("_REVIEWSLETTER","Recenzje do listw");
define("_NOREVIEWS","Nie ma adnych recenzji do listw");
define("_TOTALREVIEWS","W sumie znalezionych recenzji.");
define("_RETURN2MAIN","Powrt do gwnego menu");
define("_REVIEWCOMMENT","Komentarz do recenzji:");
define("_YOURNICK","Twj pseudonim:");
define("_RCREATEACCOUNT","<a href=user.php>Za</a> konto");
define("_YOURCOMMENT","Twj komentarz:");
define("_MYSCORE","Mj wynik:");
define("_REVIEWMOD","Modyfikacja recenzji");
define("_RDATE","Data:");
define("_RTITLE","Tytu:");
define("_RTEXT","Tekst:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Tytu linku:");
define("_COVERIMAGE","Grafika tytuowa:");
define("_PREMODS","Przejrzyj modyfikacje");
define("_PAGE","Strona");
define("_PAGEBREAK","Jeli chcesz kilka stron moesz napisa <b>&lt;!--pagebreak--&gt;</b> w miejscu, gdzie chcesz rozdzieli.<BR>");
define("_PREVIEW","Podgld");
define("_LANGUAGE","Jzyk");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-polish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Poprzednia strona");
define("_NEXT","Nastpna strona");
define("_YOURNAME","Twoje imi i nazwisko");
define("_SORTASC","Sortuj rosnco");
define("_SORTDESC","Sortuj malejco");
define("_CANCEL","Anuluj");
define("_YES","Tak");
define("_NO","Nie");
define("_SCORE","Wynik:");
define("_REPLYMAIN","Komentarz kocowy");
define("_ALLOWEDHTML","Dozwolony HTML:");
define("_POSTANON","Wylij anonimowo");
define("_WRITEREVIEW","Napisz recenzj");
define("_WRITEREVIEWFOR","Napisz recenzj dla");
define("_ENTERINFO","Prosimy wpisa informacje zgodnie z zaleceniami");
define("_PRODUCTTITLE","Nazwa produktu");
define("_NAMEPRODUCT","Nazwa recenzowanego produktu.");
define("_REVIEW","Recenzja");
define("_CHECKREVIEW","Twoja aktualna recenzja. Prosimy obserwowa poprawno gramatyczn! Zmie si w 100 sowach, OK? Moesz take uy tagw HTML, jeli wiesz jak ich uywa.");
define("_FULLNAMEREQ","Twoje pene imi i nazwisko. Wymagane.");
define("_REMAIL","Twj email");
define("_REMAILREQ","Twj adres email. Wymagany.");
define("_SELECTSCORE","Wynik tego produktu");
define("_RELATEDLINK","Link");
define("_PRODUCTSITE","Oficjalna strona WWW. Upewnij si, e adres zaczyna si od \"http://\"");
define("_LINKTITLE","Tytu linku");
define("_LINKTITLEREQ","Wymagane, jeli podae link, w innym przypadku - nie.");
define("_RIMAGEFILE","Nazwa pliku z grafik");
define("_RIMAGEFILEREQ","Nazwa tytuowej grafiki, znajdujcej si w images/reviews/. Nie wymagana.");
define("_CHECKINFO","Prosimy upewni si, e wpisana informacja jest w 100% poprawna i uywa poprawnej gramatyki. Przykadowo - prosimy nie pisa wszystkiego DUYMI LITERAMI, bo to odrzucimy.");
define("_INVALIDTITLE","Niepoprawna nazwa... Nie moe by pusta");
define("_INVALIDSCORE","Niepoprawny wynik... Musi by pomidzy 1 a 10");
define("_INVALIDTEXT","Niepoprawna tre... Nie moe by pusta");
define("_INVALIDHITS","Odsony musz by wartoci dodatni");
define("_CHECKNAME","Musisz wpisa zarwno imi, jak i adres email");
define("_INVALIDEMAIL","Niepoprawny email (np: uzytkownik@serwer.pl)");
define("_INVALIDLINK","Musisz wpisa zarwno tytu linku i sam link, albo oba zostawi puste");
define("_ADDED","Dodane:");
define("_REVIEWER","Recenzent:");
define("_REVIEWID","ID recenzji");
define("_HITS","Odson");
define("_LOOKSRIGHT","Czy to wyglda dobrze?");
define("_RMODIFIED","modyfikowane");
define("_RADDED","dodane");
define("_ADMINLOGGED","Bieco zalogowany jako administrator... recenzja zostanie niezwocznie");
define("_RTHANKS","Dzikujemy za wysanie recenzji");
define("_MODIFICATION","modyfikacje");
define("_ISAVAILABLE","Ju jest dostpna w bazie recenzji.");
define("_EDITORWILLLOOK","Redaktorzy spojrz na Twoj recenzj. Powinna by wkrtce dostpna!");
define("_RBACK","Powrt do indeksu recenzji");
define("_RWELCOME","Witamy w sekcji recenzji");
define("_10MOSTPOP","10 najpopularniejszych recenzji");
define("_10MOSTREC","10 ostatnich recenzji");
define("_THEREARE","Aktualnie jest(s)");
define("_REVIEWSINDB","recenzji(e) w bazie");
define("_REVIEWS","Recenzje");
define("_REVIEWSLETTER","Recenzje do listw");
define("_NOREVIEWS","Nie ma adnych recenzji do listw");
define("_TOTALREVIEWS","W sumie znalezionych recenzji.");
define("_RETURN2MAIN","Powrt do gwnego menu");
define("_REVIEWCOMMENT","Komentarz do recenzji:");
define("_YOURNICK","Twj pseudonim:");
define("_RCREATEACCOUNT","<a href=user.php>Za</a> konto");
define("_YOURCOMMENT","Twj komentarz:");
define("_MYSCORE","Mj wynik:");
define("_REVIEWMOD","Modyfikacja recenzji");
define("_RDATE","Data:");
define("_RTITLE","Tytu:");
define("_RTEXT","Tekst:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Tytu linku:");
define("_COVERIMAGE","Grafika tytuowa:");
define("_PREMODS","Przejrzyj modyfikacje");
define("_PAGE","Strona");
define("_PAGEBREAK","Jeli chcesz kilka stron moesz napisa <b>&lt;!--pagebreak--&gt;</b> w miejscu, gdzie chcesz rozdzieli.<BR>");
define("_PREVIEW","Podgld");
define("_LANGUAGE","Jzyk");

?>
